<?php

/*
| Parametros que o Unifi fornece:
|
| $_GET['id']; // MAC do dispositivo
| $_GET['url']; // url redirect
| $_GET['ssid']; // SSID do AP
| $_GET['ap']; // MAC do Unifi
|
*/

session_start();
require_once __DIR__ . '/vendor/autoload.php';

/* obtencao das configuracoes gerais */
$tipoMetodoAutenticacao = $conf['general']['tipo_metodo_autenticacao'];
$urlDefault = $conf['general']['url_default'];
$tempoRedirecionamento = $conf['general']['tempo_redirecionamento'];

if (array_key_exists('cadastro_realizado', $_SESSION)) {
    $mensagem = $_SESSION['cadastro_realizado'];
    $class = 'alert alert-success';
}

if(isset($_GET['id'])) { // provavelmente o usuario chegou nessa pagina atraves do redirect do proprio Unifi

  $mac = filter_input(INPUT_GET, 'id');
  $ap = filter_input(INPUT_GET, 'ap'); // obtem o MAC do equipamento

/*
  $mac = $_GET['id'];
  $ap = $_GET['ap']; // obtem o MAC do unifi
*/

  //$url = isset($_GET['url']) ? $_GET['url'] : $urlDefault;
  $url = $urlDefault;

  $_SESSION['mac'] = $mac;
  $_SESSION['ap'] = $ap;
  $_SESSION['url']= $url;
  $_SESSION['token'] = 'wg0G01asLivre'; // apenas por questao de seguranca para evitar que o formulario de cadastro seja chamado externamente

} elseif(isset($_SESSION['mac'])) { // o usuario provavelmente fez o cadastro e voltou para a tela inicial pra realizar a autenticacao

  $mac = $_SESSION['mac'];
  $url = $_SESSION['url'];
  $ap = $_SESSION['ap'];

} else { // talvez o usuario acessou a pagina diretamente pelo browser, i.e., sem usar o Unifi
  include('acesso_direto.php');
  exit;
}

if(isset($_POST['acessar'])) { // usuario clicou no botao de acessar

  $codigoAcesso = isset($_POST['codigo_acesso']) ? trim($_POST['codigo_acesso']) : '';

  if($codigoAcesso == '') {
    $mensagem = 'O código de acesso deve ser fornecido!';
    $class = 'alert alert-warning';
  } else { // ha dados para tentar a autenticacao

    // dados Unifi
    $usernameUnifi = $conf['equipamento']['username'];
    $passwordUnifi = $conf['equipamento']['password'];
    $accessUrlUnifi = $conf['equipamento']['url'];
    $siteNameUnifi = $conf['equipamento']['siteName'];

    $app = new App();
    $pin = new Pin();

    if($app->autenticar($pin, ['mac' => $mac, 'pin' => $codigoAcesso], $tipoMetodoAutenticacao)) { // se autenticar, entao concede o acesso no Unifi

      // registra o historico de acesso
      $acesso = Acesso::create(['mac' => $mac, 'ip' => get_ip(), 'access_point' => $ap]);

      $app->concederAcesso(new Unifi($usernameUnifi, $passwordUnifi, $accessUrlUnifi, $siteNameUnifi), $mac, $app->getTempoAcessoLiberado($pin));
      $app->concederAcesso(new Unifi($usernameUnifi, $passwordUnifi, $accessUrlUnifi, $siteNameUnifi), $mac, $app->getTempoAcessoLiberado($pin));

      $mensagem = 'Autenticação realizada. Aguarde o redirecionamento!';
      $class = 'alert alert-success';

      $app->redirecionar($url, $tempoRedirecionamento);

    } else { // autenticacao invalida
      $mensagem = 'Erro na autenticação: código inválido ou limite atingido!';
      $class = 'alert alert-warning';
    }
  }
}

?>

<!DOCTYPE html>
<html lang="pt_br">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Catalão Conectado</title>

    <!-- Bootstrap -->
    <link href="css/bootstrap.min.css" rel="stylesheet">
    <link href="css/bootstrap-theme.css" rel="stylesheet">

    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
      <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->
  </head>
  <body>
    <div class="geral container">
     <header>
        <div class="col-md-6 col-sm-6 col-xs-6">
          <a href="http://www.catalao.go.gov.br/" target="_blank"> <img class="img-responsive pull-left"  src="images/logo_projeto.png"></a>
        </div>
        <div class="col-md-6 col-sm-6 col-xs-6 text-right">
          <a href="http://www.catalao.go.gov.br/" target="_blank"> <img class="img-responsive pull-right" src="images/logo.png"></a>
        </div>
        <div class="col-md-12 col-sm-12 col-xs-12">
         <h3 class="text-center text-slogan"><em>Catalão Conectado</em>, <BR>nossa <em>NOVA INCLUSÃO DIGITAL</em></h3>
        </div>
      </header>
      <div class="content">

        <div class="col-md-4 col-sm-5 col-xs-12">

          <?php
            if(isset($mensagem)): ?>

          <br />
          <div class="<?=$class;?>">
            <p><?=$mensagem; ?></p>
          </div>

          <?php endif; ?>

          <form role="form" method="post" action="<?=$_SERVER['PHP_SELF']; ?>">
              <h3 class="form-signin-heading"><strong>Código de Acesso</strong></h3>
              <div class="form-group">
                 <input type="text" class="form-control" maxlength="8" placeholder="Insira aqui seu código de acesso" id="codigo_acesso" name="codigo_acesso" required="" autofocus="">
              </div>

              <div class="form-group">
                <input class="btn btn-success center-block" type="submit" name="acessar" value="ACESSAR">
                 <br>
              </div>

              <div class="center-block">
                <a href="register" class="btn btn-md btn-primary">Criar conta</a>
                <a href="recover" class="btn btn-default">Recuperar código</a>
              </div>

<!--
              <div class="form-group">
                <input class="btn btn-success center-block" type="submit" name="acessar" value="ACESSAR">
                 <br>
                 <a href="register" class="btn btn-cadastrar btn-primary">CADASTRAR</a>
                 <a href="register" class="btn btn-cadastrar btn-primary">CADASTRAR</a>
              </div>
-->
          </form>
          <br>
        </div>
        <div class="col-md-8 col-sm-7 col-xs-12 text-center">
          <br />
          <p class="text-center">Bem-vindo ao projeto <strong>Catalão Conectado</strong>.</p>
          <p class="text-center">Catalão Conectado é um projeto de inclusão digital proporcionado pelo <strong>Governo de Goiás</strong>.</p>
        </div>

      </div> <!-- end content -->

      <footer style="clear:both">

        <!--<a href="index.php" class="btn btn-info">Inicio</a>-->

        <!-- INSTRUÇÃO INSIRIR MAIS LOGOS ABAIXO

        SIMPLES FORMULA MATEMATICA ( QUANTIDADE DE LOGO/12 ) == col-md-RESULTADO col-sm-RESULTADO col-xs-RESULTADO

        EXEMPLO: TEM 3 LOGOS ( 3/12 ) == col-md-4 col-sm-4 col-xs-4

        DAI E SO INSERIR A DIV ABAIXO

        <div class="col-md-4 col-sm-4 col-xs-4">
          <a href="http://www.wgo.com.br" target="_blank"><img class="pull-right" src="images/logo_wgo.png"></a>
        </div>

      -->

       <div class="col-md-6 col-sm-6 col-xs-6">
          <a href="http://www.wgo.com.br" target="_blank"><img class="pull-left" src="images/logo_wifi.png"></a>
        </div>
        <div class="col-md-6 col-sm-6 col-xs-6">
          <a href="http://www.wgo.com.br" target="_blank"><img class="pull-right" src="images/logo_wgo.png"></a>
        </div>
      </footer>
    </div> <!-- end container -->

    <!-- jQuery (necessary for Bootstrap's JavaScript plugins) -->
    <script src="js/jquery.min.js"></script>
    <!-- Include all compiled plugins (below), or include individual files as needed -->
    <script src="js/bootstrap.min.js"></script>
  </body>
</html>
