<?php

class User extends ActiveRecord\Model implements UserInterface {

	static $validates_presence_of = [
		['nome', 'message' => 'deve ser fornecido!'],
		['telefone', 'message' => 'celular deve ser fornecido!'],
		['cpf', 'message' => 'deve ser fornecido!'],
	];

    static $validates_length_of = [
        ['telefone', 'within' => [10, 11], 'too_short' => 'celular inválido!', 'too_long' => 'celular inválido!'],
        ['cpf', 'is' => 11, 'wrong_length' => 'deve conter 11 dígitos!'],
    ];

    static $validates_numericality_of = [
        ['telefone', 'only_integer' => true, 'message' => 'celular deve ser apenas numérico!'],
        ['cpf', 'only_integer' => true, 'message' => 'deve ser apenas numérico!'],
    ];

	public function validate() {

		// valida o email apenas se o mesmo tiver sido fornecido
		if(trim($this->email) != '' && preg_match('/^[^0-9][A-z0-9_]+([.][A-z0-9_]+)*[@][A-z0-9_]+([.][A-z0-9_]+)*[.][A-z]{2,4}$/', $this->email) === 0) {
			$this->errors->add('email', 'inválido!');
		}

		if(count(explode(' ', trim($this->nome))) < 2) { // o nome digitado deve ser completo, ou seja, composto de 2 ou mais partes
			$this->errors->add('nome', 'deve ser completo!');
		}

		if (! validaCPF($this->cpf)) {
			$this->errors->add('cpf', 'inválido!');
		}
	}
}
