<?php

/*
|-------------------------------------------------------------
| register.php
|-------------------------------------------------------------
| contem o formulario para cadastro de um novo usuario
| ou o botao para recuperar o codigo de acesso
|
*/

session_start();
require_once __DIR__ . '/vendor/autoload.php';

/* obtencao das configuracoes gerais */
$tipoMetodoAutenticacao = $conf['general']['tipo_metodo_autenticacao'];
$tempoAcessoLiberado = $conf['general']['tempo_acesso_liberado'];
$periodicity = $conf['general']['periodicity'];
$max_number_auth = $conf['general']['max_number_auth'];

$msgSucesso = '';
$msgErro = '';

if(!isset($_SESSION['mac'])) { // usuario chegou nessa tela usando o endereco direto no browser, ou seja, sem passar pelo UniFi
	include('acesso_direto.php');
	exit;
} else {
    $mac = $_SESSION['mac'];
    $ap = $_SESSION['ap'];

    $app = new App();

    if($app->temCodigoAcesso(new Pin(), ['mac' => $mac])) { // ja existe um codigo de acesso para o MAC em questao. Assim, exibe a pagina perguntando se o usuario deseja recuperar esse codigo
    	include('recuperar_codigo_acesso.php');
    	exit;
    } else { // ainda nao ha codigo de acesso para o MAC em questao, entao possibilita o cadastro

        if(isset($_POST['cadastrar']) && isset($_SESSION['token']) && $_SESSION['token'] == 'wg0G01asLivre') { // usuario pressionou o botao de cadastrar e o token foi validado

            $dadosUsuario = array_map('trim', $_POST);
            $nome = $dadosUsuario['nome'];
            $telefone = clean_string($dadosUsuario['telefone']);
            // $email = $dadosUsuario['email'];
            $cpf = clean_string($dadosUsuario['cpf']);

        	if(!isset($_POST['aceitou'])) {
        		$msgErro = '<p>Termos de uso devem ser aceitos!</p>';
        	} else { // aceitou o termo de uso

	            $user = User::create(['nome' => $nome, 'telefone' => $telefone, 'cpf' => $cpf]);

	            if($user->is_valid()) { // dados salvos com sucesso, entao gera codigo de acesso, grava na tabela, dispara SMS para o usuario e exibe mensagem

	                $codigoAcesso = $app->gerarCodigoAcesso(new Pin());
	                $pin = Pin::create(
                                      ['user_id' => $user->id, 'mac' => $mac, 'created_at_access_point' => $ap, 'pin' => $codigoAcesso,
                                      'current_number_auth' => 0, 'max_number_auth' => $max_number_auth, 'periodicity' => $periodicity,
                                      'time_to_live' => $tempoAcessoLiberado, 'ip' => get_ip(), ]
                                    );

	                if($pin->is_valid()) { // dados salvos no banco, entao dispara SMS com o codigo de acesso

                    $vendorSMS = $conf['sms'];
                    $username = $conf['vendor']['sms'][$vendorSMS]['username'];
                    $password = $conf['vendor']['sms'][$vendorSMS]['password'];
                    $endereco = $conf['vendor']['sms'][$vendorSMS]['endereco'];
                    $remetente = $conf['vendor']['sms'][$vendorSMS]['remetente'];

		                $mensagemSMS = fmt_string(sprintf("Obrigado por se cadastrar no projeto Catalao Conectado. Ha um limite de 2h continuas de acesso diario. Seu codigo de acesso: {$codigoAcesso}"));

	                    try {
	                       $app->dispararSMS(SMSFactory::create($vendorSMS, $username, $password, $endereco), '55'.$telefone, $mensagemSMS, $remetente);
                           $_SESSION['cadastro_realizado'] = 'Cadastro realizado e código de acesso enviado por SMS';
                           $app->redirecionar('index', 2);
	                    } catch(Exception $e) {
	                       $msgErro .= '<p>'.$e->getMessage().'</p>';
	                    }
	                }
	            }
        	}
        }
    }
}

?>

<!DOCTYPE html>
<html lang="pt_br">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Catalão Conectado</title>

    <!-- Bootstrap -->
    <link href="css/bootstrap.min.css" rel="stylesheet">
    <link href="css/bootstrap-theme.css" rel="stylesheet">

    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
      <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
      <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->
  </head>
  <body>
    <div class="geral container">
      <header>
        <div class="col-md-12 col-sm-12 col-xs-12 text-center">
          <a href="http://www.catalao.go.gov.br/" target="_blank"><img src="images/logo_projeto.png"></a>
        </div>
      </header>
      <div class="content">

        <div class="col-md-6 col-sm-6 col-xs-12">
          <br />

          <?php

            // constroi as mensagens de erro do usuario
            if(isset($user) && $user->is_invalid()) {
              foreach($user->errors->full_messages() as $error) {
                $msgErro .= "<p>{$error}</p>";
              }
            }

            // constroi as mensagens de erro do pin
            if(isset($pin) && $pin->is_invalid()) {
              foreach($pin->errors->full_messages() as $error) {
                $msgErro .= "<p>{$error}</p>";
              }
          }

          // imprime mensagens de erro, se houver
          if($msgErro): ?>
            <div class="alert alert-warning">
              <?=$msgErro; ?>
            </div>
          <?php endif; ?>

          <?php

          // imprime mensagens de sucesso, se houver
          if($msgSucesso): ?>
            <div class="alert alert-success">
              <?=$msgSucesso; ?>
            </div>
          <?php endif; ?>

          <form role="form" method="post" action="<?=$_SERVER['PHP_SELF']; ?>">
              <h3 class="form-signin-heading"><strong>CADASTRO</strong></h3>
              <div class="form-group">
                <label for="nome">Nome</label>
                 <input type="text" class="form-control" placeholder="Insira seu nome completo" id="nome" name="nome" value="<?= isset($_POST['nome']) ? $_POST['nome'] : ''; ?>" required autofocus>
              </div>
              <div class="form-group">
                <label for="telefone">DDD + Celular <em>(ex.: 6481251169)</em></label>
                <input type="tel" class="form-control" maxlength="11" placeholder="DDD+Celular" id="telefone" name="telefone" value="<?= isset($_POST['telefone']) ? $_POST['telefone'] : ''; ?>" required>
              </div>
              <div class="form-group">
                <label for="cpf">CPF (apenas números)</label>
                <input type="tel" maxlength="11" class="form-control" placeholder="Insira seu CPF" id="cpf" name="cpf" value="<?= isset($_POST['cpf']) ? $_POST['cpf'] : ''; ?>" required>
              </div>
              <div class="checkbox">
                <label>
                  <input type="checkbox" value="S" name="aceitou">Aceito os termos de uso
                </label>
              </div>
              <div class="center-block">
                <input class="btn btn-md btn-primary" type="submit" name="cadastrar" value="CADASTRAR">
                <a href="index" class="btn btn-md btn-success">INÍCIO</a>
              </div>
          </form>
        </div>
        <div class="col-md-6 col-sm-6 col-xs-12">
          <h2><strong>TERMOS DE USO</strong></h2>
          <p>Para receber o código de acesso é necessário realizar o cadastro através do formulário.</p>
          <p>O código de acesso será enviado por <strong>SMS</strong> para o número de telefone celular informado no cadastro.</p>
          <p><strong>Notas:</strong></p>
          <ul>
            <li><p>A mensagem <em>SMS</em> pode levar até 3min para ser entregue. Caso não ocorra o recebimento da mesma, utilize a opção <strong>Recuperar Código</strong> disponível na página inicial.</p></li>
            <li><p>O usuário tem direito a <em>2h</em> contínuas de acesso diário.</p></li>
          </ul>
        </div>

      </div> <!-- end content -->

       <footer style="clear:both">
       <br />
       <br />
        <div class="col-md-6 col-sm-6 col-xs-6">
          <div class="col-md-2 col-sm-6 col-xs-6">
            <a href="http://www.wgo.com.br" target="_blank"><img class="pull-left img-responsive" src="images/logo_wifi.png"></a>
          </div>
          <div class="col-md-3 col-sm-6 col-xs-6">
            <a href="http://www.catalao.go.gov.br/" target="_blank"><img class="pull-left img-responsive" src="images/logo_small.png"></a>
          </div>
        </div>
        <div class="col-md-6 col-sm-6 col-xs-3">
          <a href="http://www.wgo.com.br" target="_blank"><img class="pull-right img-responsive" src="images/logo_wgo.png"></a>
        </div>
      </footer>
    </div> <!-- end container -->
    <br />
    <!-- jQuery (necessary for Bootstrap's JavaScript plugins) -->
    <script src="js/jquery.min.js"></script>
    <!-- Include all compiled plugins (below), or include individual files as needed -->
    <script src="js/bootstrap.min.js"></script>
    <script src="js/jquery.maskedinput.js"></script>
    <script src="js/app.js"></script>
  </body>
</html>
