<?php

/*
|------------------------------------------
| helpers.php
|------------------------------------------
|
*/

function get_ip() {
    $ipaddress = '';
    if (getenv('HTTP_CLIENT_IP'))
        $ipaddress = getenv('HTTP_CLIENT_IP');
    else if(getenv('HTTP_X_FORWARDED_FOR'))
        $ipaddress = getenv('HTTP_X_FORWARDED_FOR');
    else if(getenv('HTTP_X_FORWARDED'))
        $ipaddress = getenv('HTTP_X_FORWARDED');
    else if(getenv('HTTP_FORWARDED_FOR'))
        $ipaddress = getenv('HTTP_FORWARDED_FOR');
    else if(getenv('HTTP_FORWARDED'))
        $ipaddress = getenv('HTTP_FORWARDED');
    else if(getenv('REMOTE_ADDR'))
        $ipaddress = getenv('REMOTE_ADDR');
    else
        $ipaddress = '0.0.0.0';

    return $ipaddress;
}

function validaCPF($cpf = null) {

    // verifica se um numero foi informado
	if(empty($cpf)) {
		return false;
	}

    // elimina possivel mascara
	$cpf = preg_replace( '/[^0-9]/is', '', $cpf );
	$cpf = str_pad($cpf, 11, '0', STR_PAD_LEFT);

    // Verifica se o numero de digitos informados eh igual a 11
	if (mb_strlen($cpf) != 11) {
		return false;
	}

    // verifica se nenhuma das sequencias invalidas abaixo foi digitada. Caso afirmativo, retorna falso
	elseif ($cpf == '00000000000' ||
		$cpf == '11111111111' ||
		$cpf == '22222222222' ||
		$cpf == '33333333333' ||
		$cpf == '44444444444' ||
		$cpf == '55555555555' ||
		$cpf == '66666666666' ||
		$cpf == '77777777777' ||
		$cpf == '88888888888' ||
		$cpf == '99999999999') {
		return false;
     } else { // calcula os digitos verificadores para verificar se o CPF eh valido

     	for ($t = 9; $t < 11; $t++) {
     		for ($d = 0, $c = 0; $c < $t; $c++) {
     			$d += $cpf{$c} * (($t + 1) - $c);
     		}
     		$d = ((10 * $d) % 11) % 10;
     		if ($cpf{$c} != $d) {
     			return false;
     		}
     	}

     	return true;
     }
 }

/**
 * Limpa uma string, ou seja, removendo caracteres
 * @param  string $string A string a ser limpada
 * @return string         A string com os caracteres removidos
 */
function clean_string($string) {
	return preg_replace('/[^0-9]/', '', $string);
}

/**
* Formata string. Retira acentos/caracteres especiais de uma string
* @author rod@wgo.com.br
* @version 1
* @since 2014-04-02
* @param  string $string A string a ser formatada
* @return string         A string sem acentos/caracteres especiais
*/
function fmt_string($string)  {
	$array1 = array("á", "à", "â", "ã", "ä", "é", "è", "ê", "ë", "í", "ì", "î", "ï", "ó", "ò", "ô", "õ", "ö", "ú", "ù", "û", "ü", "ç", "Á", "À", "Â", "Ã", "Ä", "É", "È", "Ê", "Ë", "Í", "Ì", "Î", "Ï", "Ó", "Ò", "Ô", "Õ", "Ö", "Ú", "Ù", "Û", "Ü", "Ç");
	$array2 = array("a", "a", "a", "a", "a", "e", "e", "e", "e", "i", "i", "i", "i", "o", "o", "o", "o", "o", "u", "u", "u", "u", "c", "A", "A", "A", "A", "A", "E", "E", "E", "E", "I", "I", "I", "I", "O", "O", "O", "O", "O", "U", "U", "U", "U", "C");
	return str_replace($array1, $array2, $string);
}

/**
* Inspeciona/debuga uma variavel
* @param mix $var A variavel sendo inspecionada
* @param bool $usar_var_dump Indica se sera usado var_dump() ou print_r(). Por padrao, eh usado print_r()
* @author rod <rod@wgo.com.br>
* @version 1
* @since 2014-02-20
*/
function inspect($var, $usar_var_dump = false) {
	echo '<pre>';
	if($usar_var_dump) {
		var_dump($var);
	} else {
		print_r($var);
	}
	echo '</pre>';
}

/**
* Dump and die
* @param mix $var A variavel sendo inspecionada
* @param bool $usar_var_dump Indica se sera usado var_dump() ou print_r(). Por padrao, eh usado print_r()
* @author rod <rod@wgo.com.br>
* @version 1
* @since 2014-03-19
*/
function dd($var, $usar_var_dump = false) {
	inspect($var, $usar_var_dump);
	exit;
}

//*********************************************************************************************
// DateToMysql
//
//  Ver 1.0.0 - Coró - 20/03/2003
//  Alteracao - Guilherme - 11/06/2007 - permitir data formato x/x/xxxx
//**********************************
function DateToMysql( $data='00/00/0000' ) {
    if ( $data=='00/00/0000' or $data == '' ) {
        return '0000-00-00';
    } else {
        $aux = explode ( "/", $data );
        return padr( $aux[2], 4, '0') .'-'.padr( $aux[1], 2, '0' ).'-'.padr( $aux[0], 2, '0' );
    }
}

//*********************************************************************************************
// padr - Alinha string a direita
//
//  Ver 1.0.0 - Coró - 15/06/2000
//**********************************
function padr( $str, $len, $char ) {
  $str = str_repeat( $char, $len ) . $str ;
  Return substr( $str,-($len) );
}

